==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AdditionalNetworkDefinitionFluent<A extends io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getNamespace();
  public A withNamespace(java.lang.String namespace);
  public java.lang.Boolean hasNamespace();
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0);
  public java.lang.String getRawCNIConfig();
  public A withRawCNIConfig(java.lang.String rawCNIConfig);
  public java.lang.Boolean hasRawCNIConfig();
  
  /**
   * Method is deprecated. use withRawCNIConfig instead.
   */
  @java.lang.Deprecated
  public A withNewRawCNIConfig(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSimpleMacvlanConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig getSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig buildSimpleMacvlanConfig();
  public A withSimpleMacvlanConfig(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig simpleMacvlanConfig);
  public java.lang.Boolean hasSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item);
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public interface SimpleMacvlanConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigFluent<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<N>>{
    public N and();
    public N endSimpleMacvlanConfig();
    
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AdditionalNetworkDefinitionFluent<A extends io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getNamespace();
  public A withNamespace(java.lang.String namespace);
  public java.lang.Boolean hasNamespace();
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0);
  public java.lang.String getRawCNIConfig();
  public A withRawCNIConfig(java.lang.String rawCNIConfig);
  public java.lang.Boolean hasRawCNIConfig();
  
  /**
   * Method is deprecated. use withRawCNIConfig instead.
   */
  @java.lang.Deprecated
  public A withNewRawCNIConfig(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSimpleMacvlanConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig getSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig buildSimpleMacvlanConfig();
  public A withSimpleMacvlanConfig(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig simpleMacvlanConfig);
  public java.lang.Boolean hasSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item);
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfig();
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface SimpleMacvlanConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigFluent<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<N>>{
    public N and();
    public N endSimpleMacvlanConfig();
    
  }
  
}
